@@ -8,12 +8,20 @@ packageStartupMessage("The BrailleR.View,  option is set to FALSE.")
 }
 
 .onLoad=function(libname, pkgname){
-if(system.file("PREFERENCES", package="BrailleR")==""){# first time package is used
-    DefSettings=system.file("DEFAULTS", package="BrailleR")
-    PrefSettings=sub("DEFAULTS", "PREFERENCES", DefSettings)
-    file.copy(DefSettings, PrefSettings)}
-options(BrailleR.View=interactive())
-OpSet=read.dcf(system.file("PREFERENCES", package="BrailleR"), all=TRUE)
+    ns <- getNamespace(pkgname)
+#    pkg <- Package(pkgname)
+#    assign(pkgname, pkg, envir = ns)
+
+Folder =     SetupBrailleR()
+
+if(file.exists("BrailleROptions")){OpSet=read.dcf("BrailleROptions", all=TRUE)}
+else { # first time package is used in this directory
+OpSet = read.dcf(paste0(Folder, "BrailleROptions"), all=TRUE)
+# to do: # ask for permission to write a local copy
+## write.dcf(OpSet, file="BrailleROptions")
+}
+
+OpSet$BrailleR.Folder=Folder
 OpSet$BrailleR.SigLevel=as.numeric(OpSet$BrailleR.SigLevel)
 OpSet$BrailleR.PValDigits=as.numeric(OpSet$BrailleR.PValDigits)
 OpSet$BrailleR.DotplotBins=as.numeric(OpSet$BrailleR.DotplotBins)
@@ -21,10 +29,17 @@ OpSet$BrailleR.BRLPointSize = as.numeric(OpSet$BrailleR.BRLPointSize)
 OpSet$BrailleR.PaperWidth = as.numeric(OpSet$BrailleR.PaperWidth)
 OpSet$BrailleR.PaperHeight = as.numeric(OpSet$BrailleR.PaperHeight)
 #OpSet$ = as.numeric(OpSet$)
+
 do.call(options, as.list(OpSet))
+Op <- getOption("repos")
+Op["CRAN"] <- "https://cran.rstudio.com/"
+options(repos=Op)
+
+
+
+options(BrailleR.View=interactive())
 BrailleR=new.env(parent=.GlobalEnv)
 if(interactive()){
-utils::chooseCRANmirror(ind=1)
 options("menu.graphics"=FALSE)
 }
 }
