@@ -9,3 +9,6 @@
 ## ----start---------------------------------------------------------------
 library(BrailleR)
 
+## ----SetAuthor-----------------------------------------------------------
+SetAuthor("Jonathan Godfrey")
+
